"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Endpoint = void 0;
var Endpoint;
(function (Endpoint) {
    const CONTRIBUTORS = 'contributors';
    const DEPENDENCIES = 'dependencies';
    const DEPENDENT_REPOSITORIES = 'dependent_repositories';
    const DEPENDENTS = 'dependents';
    const GITHUB = 'github';
    const PLATFORMS = 'platforms';
    const PROJECT_CONTRIBUTIONS = 'project-contributions';
    const PROJECTS = 'projects';
    const REPOSITORIES = 'repositories';
    const REPOSITORY_CONTRIBUTIONS = 'repository-contributions';
    const SEARCH = 'search';
    const SOURCERANK = 'sourcerank';
    const SUBSCRIPTIONS = 'subscriptions';
    const USAGE = 'usage';
    const encode = encodeURIComponent;
    let Project;
    (function (Project) {
        function contributors(platform, name) {
            return `/${encode(platform)}/${encode(name)}/${CONTRIBUTORS}/`;
        }
        Project.contributors = contributors;
        function dependencies(platform, name, version) {
            return `/${encode(platform)}/${encode(name)}/${encode(version)}/${DEPENDENCIES}/`;
        }
        Project.dependencies = dependencies;
        function dependentRepositories(platform, name) {
            return `/${encode(platform)}/${encode(name)}/${DEPENDENT_REPOSITORIES}/`;
        }
        Project.dependentRepositories = dependentRepositories;
        function dependents(platform, name) {
            return `/${encode(platform)}/${encode(name)}/${DEPENDENTS}/`;
        }
        Project.dependents = dependents;
        function search() {
            return `/${SEARCH}/`;
        }
        Project.search = search;
        function sourceRank(platform, name) {
            return `/${encode(platform)}/${encode(name)}/${SOURCERANK}/`;
        }
        Project.sourceRank = sourceRank;
        function subscriptions(platform, name) {
            return `/${SUBSCRIPTIONS}/${encode(platform)}/${encode(name)}/`;
        }
        Project.subscriptions = subscriptions;
        function usage(platform, name) {
            return `/${encode(platform)}/${encode(name)}/${USAGE}/`;
        }
        Project.usage = usage;
        function project(platform, name) {
            return `/${encode(platform)}/${encode(name)}/`;
        }
        Project.project = project;
    })(Project = Endpoint.Project || (Endpoint.Project = {}));
    let GitHub;
    (function (GitHub) {
        let Repository;
        (function (Repository) {
            function dependencies(owner, name) {
                return `/${GITHUB}/${encode(owner)}/${encode(name)}/${DEPENDENCIES}/`;
            }
            Repository.dependencies = dependencies;
            function projects(owner, name) {
                return `/${GITHUB}/${encode(owner)}/${encode(name)}/${PROJECTS}/`;
            }
            Repository.projects = projects;
            function repository(owner, name) {
                return `/${GITHUB}/${encode(owner)}/${encode(name)}/`;
            }
            Repository.repository = repository;
        })(Repository = GitHub.Repository || (GitHub.Repository = {}));
        let User;
        (function (User) {
            function dependencies(login) {
                return `/${GITHUB}/${encode(login)}/${DEPENDENCIES}/`;
            }
            User.dependencies = dependencies;
            function packages(login) {
                return `/${GITHUB}/${encode(login)}/${PROJECTS}/`;
            }
            User.packages = packages;
            function projects(login) {
                return `/${GITHUB}/${encode(login)}/${PROJECTS}/`;
            }
            User.projects = projects;
            function contributedProjects(login) {
                return `/${GITHUB}/${encode(login)}/${PROJECT_CONTRIBUTIONS}/`;
            }
            User.contributedProjects = contributedProjects;
            function repositories(login) {
                return `/${GITHUB}/${encode(login)}/${REPOSITORIES}/`;
            }
            User.repositories = repositories;
            function contributedRepositories(login) {
                return `/${GITHUB}/${encode(login)}/${REPOSITORY_CONTRIBUTIONS}/`;
            }
            User.contributedRepositories = contributedRepositories;
            function user(login) {
                return `/${GITHUB}/${encode(login)}/`;
            }
            User.user = user;
        })(User = GitHub.User || (GitHub.User = {}));
    })(GitHub = Endpoint.GitHub || (Endpoint.GitHub = {}));
    function platforms() {
        return `/${PLATFORMS}/`;
    }
    Endpoint.platforms = platforms;
    function subscriptions(platform, name) {
        let endpoint = `/${SUBSCRIPTIONS}/`;
        if (platform && name) {
            endpoint += `${encode(platform)}/${encode(name)}/`;
        }
        return endpoint;
    }
    Endpoint.subscriptions = subscriptions;
})(Endpoint = exports.Endpoint || (exports.Endpoint = {}));
//# sourceMappingURL=Endpoints.js.map