"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LibrariesIO = void 0;
const axios_1 = require("axios");
const api_1 = require("./api");
class LibrariesIO {
    constructor(options) {
        if (typeof options === 'string') {
            options = { apiKey: options };
        }
        this.options = Object.assign({ apiUrl: 'https://libraries.io/api' }, options);
        this.apiClient = axios_1.default.create({
            baseURL: this.options.apiUrl,
        });
        this.apiClient.interceptors.request.use(config => {
            config.data = Object.assign(Object.assign({}, config.data), { api_key: this.options.apiKey });
            return config;
        });
        this.apiClient.interceptors.response.use(response => {
            const headers = response.headers;
            const totalResults = headers['total'] ? Number(headers['total']) : undefined;
            return Object.assign(Object.assign({}, response), { totalResults });
        });
        this.api = {
            github: {
                repository: new api_1.GitHubRepositoryAPI(this.apiClient, this.options),
                user: new api_1.GitHubUserAPI(this.apiClient, this.options),
            },
            platform: new api_1.PlatformAPI(this.apiClient, this.options),
            project: new api_1.ProjectAPI(this.apiClient, this.options),
            user: new api_1.UserAPI(this.apiClient, this.options),
        };
    }
    /**
     * Set a new API key.
     * @param apiKey The new API key
     */
    setApiKey(apiKey) {
        this.options.apiKey = apiKey;
    }
    /*
  
        const contentType = headers['content-type'] ? String(headers['content-type']) : undefined;
        const rateLimit = Number(headers['x-ratelimit-limit']);
        const rateLimitRemaining = Number(headers['x-ratelimit-remaining']);
        const totalResults = headers['total'] ? Number(headers['total']) : undefined;
    */
    /**
     * Set a new API URL.
     * @param newUrl The new API url
     */
    setApiUrl(newUrl) {
        this.apiClient.defaults.baseURL = newUrl;
    }
}
exports.LibrariesIO = LibrariesIO;
//# sourceMappingURL=LibrariesIO.js.map