"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitHubRepositoryAPI = void 0;
const Endpoints_1 = require("../../Endpoints");
const APIBase_1 = require("../APIBase");
class GitHubRepositoryAPI extends APIBase_1.APIBase {
    constructor(apiClient, options) {
        super(apiClient, options);
    }
    /**
     * Get a list of packages referencing the given repository.
     * @see https://libraries.io/api#repository-projects
     * @param repositoryOwner The repository owner
     * @param repositoryName The repository name
     * @param options Pagination Options
     */
    getProjects(repositoryOwner, repositoryName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.GitHub.Repository.projects(repositoryOwner, repositoryName);
            const { data } = yield this.apiClient.get(endpoint, { data: options });
            return data;
        });
    }
    /**
     * Get a info for a repository. Currently only works for open source repositories.
     * @see https://libraries.io/api#repository
     * @param repositoryOwner The repository owner
     * @param repositoryName The repository name
     */
    getRepository(repositoryOwner, repositoryName) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.GitHub.Repository.repository(repositoryOwner, repositoryName);
            const { data } = yield this.apiClient.get(endpoint);
            return data;
        });
    }
    /**
     * Get a list of dependencies for a repositories. Currently only works for open source repositories.
     * @see https://libraries.io/api#repository-dependencies
     * @param repositoryOwner The repository owner
     * @param repositoryName The repository name
     */
    getRepositoryWithDependencies(repositoryOwner, repositoryName) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.GitHub.Repository.dependencies(repositoryOwner, repositoryName);
            const { data } = yield this.apiClient.get(endpoint);
            return data;
        });
    }
}
exports.GitHubRepositoryAPI = GitHubRepositoryAPI;
//# sourceMappingURL=GitHubRepositoryAPI.js.map