import type { AxiosInstance } from 'axios';
import type { ClientOptions, Contributor, LibrariesIOResult, PaginationOptions, PlatformType, Project, Repository } from '../../interfaces/';
import { APIBase } from '../APIBase';
export declare class GitHubUserAPI extends APIBase {
    constructor(apiClient: AxiosInstance, options: ClientOptions);
    /**
     * Get a list of packages that the given user has contributed to.
     * @see https://libraries.io/api#user-project-contributions
     * @param userName The username
     * @param options Pagination options
     */
    getContributedProjects(userName: string, options?: PaginationOptions): Promise<LibrariesIOResult<Project[]>>;
    /**
     * Get a list of repositories that the given user has contributed to.
     * @see https://libraries.io/api#user-repository-contributions
     * @param userName The username
     * @param options Pagination options
     */
    getContributedRepositories(userName: string, options?: PaginationOptions): Promise<LibrariesIOResult<Repository[]>>;
    getDependencies(userName: string, options?: PaginationOptions): Promise<LibrariesIOResult<Project[]>>;
    getDependencies(userName: string, platform?: PlatformType, options?: PaginationOptions): Promise<LibrariesIOResult<Project[]>>;
    /**
     * Get a list of packages referencing the given user's repositories.
     * @see https://libraries.io/api#user-projects
     * @param userName The username
     * @param options Pagination options
     */
    getProjects(userName: string, options?: PaginationOptions): Promise<LibrariesIOResult<Project[]>>;
    /**
     * Get repositories owned by a user.
     * @see https://libraries.io/api#user-repositories
     * @param userName The username
     * @param options Pagination options
     */
    getRepositories(userName: string, options?: PaginationOptions): Promise<LibrariesIOResult<Repository[]>>;
    /**
     * Get information for a given user or organization.
     * @see https://libraries.io/api#user
     * @param userName The username
     */
    getUser(userName: string): Promise<LibrariesIOResult<Contributor>>;
}
