"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitHubUserAPI = void 0;
const Endpoints_1 = require("../../Endpoints");
const APIBase_1 = require("../APIBase");
class GitHubUserAPI extends APIBase_1.APIBase {
    constructor(apiClient, options) {
        super(apiClient, options);
    }
    /**
     * Get a list of packages that the given user has contributed to.
     * @see https://libraries.io/api#user-project-contributions
     * @param userName The username
     * @param options Pagination options
     */
    getContributedProjects(userName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.GitHub.User.contributedProjects(userName);
            const { data } = yield this.apiClient.get(endpoint, { data: options });
            return data;
        });
    }
    /**
     * Get a list of repositories that the given user has contributed to.
     * @see https://libraries.io/api#user-repository-contributions
     * @param userName The username
     * @param options Pagination options
     */
    getContributedRepositories(userName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.GitHub.User.contributedRepositories(userName);
            const { data } = yield this.apiClient.get(endpoint, { data: options });
            return data;
        });
    }
    /**
     * Get a list of unique packages that the given user's repositories list as a dependency. Ordered by frequency of use in those repositories.
     * @see https://libraries.io/api#user-dependencies
     * @param userName The username
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param options Pagination options
     */
    getDependencies(userName, platformOrOptions, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.GitHub.User.contributedRepositories(userName);
            let parameters = {};
            if (platformOrOptions) {
                if (typeof platformOrOptions === 'string') {
                    parameters = Object.assign({ platform: platformOrOptions }, options);
                }
                else {
                    parameters = platformOrOptions;
                }
            }
            const { data } = yield this.apiClient.get(endpoint, { data: parameters });
            return data;
        });
    }
    /**
     * Get a list of packages referencing the given user's repositories.
     * @see https://libraries.io/api#user-projects
     * @param userName The username
     * @param options Pagination options
     */
    getProjects(userName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.GitHub.User.repositories(userName);
            const { data } = yield this.apiClient.get(endpoint, { data: options });
            return data;
        });
    }
    /**
     * Get repositories owned by a user.
     * @see https://libraries.io/api#user-repositories
     * @param userName The username
     * @param options Pagination options
     */
    getRepositories(userName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.GitHub.User.repositories(userName);
            const { data } = yield this.apiClient.get(endpoint, { data: options });
            return data;
        });
    }
    /**
     * Get information for a given user or organization.
     * @see https://libraries.io/api#user
     * @param userName The username
     */
    getUser(userName) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.GitHub.User.user(userName);
            const { data } = yield this.apiClient.get(endpoint);
            return data;
        });
    }
}
exports.GitHubUserAPI = GitHubUserAPI;
//# sourceMappingURL=GitHubUserAPI.js.map