"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserAPI = void 0;
const Endpoints_1 = require("../Endpoints");
const APIBase_1 = require("./APIBase");
class UserAPI extends APIBase_1.APIBase {
    constructor(apiClient, options) {
        super(apiClient, options);
    }
    /**
     * List packages that a user is subscribed to recieved notifications about new releases.
     * @see https://libraries.io/api#subscriptions-index
     * @param options Pagination options
     */
    getAllSubscriptions(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.subscriptions();
            const { data } = yield this.apiClient.get(endpoint, { data: options });
            return data;
        });
    }
    /**
     * Check if a users is subscribed to receive notifications about new releases of a project.
     * @see https://libraries.io/api#subscriptions-show
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    getSubscription(platform, projectName) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.subscriptions(platform, projectName);
            const { data } = yield this.apiClient.get(endpoint);
            return data;
        });
    }
    /**
     * Subscribe to receive notifications about new releases of a project.
     * @see https://libraries.io/api#subscriptions-create
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Subscription options
     */
    subscribe(platform, projectName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.subscriptions(platform, projectName);
            const { data } = yield this.apiClient.post(endpoint, { data: options });
            return data;
        });
    }
    /**
     * Stop receiving release notifications from a project.
     * @see https://libraries.io/api#subscriptions-destroy
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    unsubscribe(platform, projectName) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.subscriptions(platform, projectName);
            const { data } = yield this.apiClient.delete(endpoint);
            return data;
        });
    }
    /**
     * Update the options for a subscription.
     * @see https://libraries.io/api#subscriptions-update
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Subscription options
     */
    updateSubscription(platform, projectName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.subscriptions(platform, projectName);
            const { data } = yield this.apiClient.put(endpoint, { data: options });
            return data;
        });
    }
}
exports.UserAPI = UserAPI;
//# sourceMappingURL=UserAPI.js.map